@@ -85,8 +85,8 @@ class ThresholdOneHotEncoder(OneHotEncoder):
         the transformed features will be retained.
     """
 
-    def __init__(self, categories=None, drop=None, sparse=True, dtype=np.float64, threshold=None, max_categories=100):
-        super().__init__(None, None, categories, drop, sparse, dtype, "ignore")
+    def __init__(self, categories="auto", drop=None, sparse=True, dtype=np.float64, threshold=None, max_categories=100):
+        super().__init__(categories=categories, drop=drop, sparse=sparse, dtype=dtype, handle_unknown="ignore")
         self.threshold = threshold
         self.max_categories = max_categories
 
@@ -109,7 +109,7 @@ class ThresholdOneHotEncoder(OneHotEncoder):
         super().fit(X, y)
         assert self.max_categories >= 1
 
-        _, n_samples, n_features = self._check_X(X)
+        n_samples, n_features = X.shape
 
         if not self.threshold:
             threshold = max(10, n_samples / 1000)
@@ -154,17 +154,9 @@ class ThresholdOneHotEncoder(OneHotEncoder):
         return self
 
     def fit_transform(self, X, y=None):
-        # This method is overloaded here in order to fix a minor bug in OneHotEncoder. See the last line of this method
         self._validate_keywords()
 
-        self._handle_deprecations(X)
-
-        if self._legacy_mode:
-            return super()._transform_selected(
-                X, self._legacy_fit_transform, self.dtype, self._categorical_features, copy=True
-            )
-        # The y was added to fit. In OneHotEncoder the next line is: return self.fit(X).transform(X)
-        return self.fit(X, y).transform(X)
+        return super().fit_transform(X, y)
 
     def _more_tags(self):
         return {"X_types": ["categorical"]}
@@ -233,20 +225,29 @@ class RobustLabelEncoder(LabelEncoder):
     fill_label_value : str (default = '<unseen_label>')
         Replacement value for unseen encoded labels during ``inverse_transform``.
 
+    include_unseen_class: boolean (default = False)
+        Whether or not ``fill_label_value`` should be included as a class.
+
     Attributes
     ----------
     classes_ : array of shape (n_classes,)
-        Holds the label for each class.
+        Holds the label for each class that is seen when the encoder is ``fit``.
     """
 
     def __init__(
-        self, labels=None, fill_unseen_labels=True, fill_encoded_label_value=None, fill_label_value="<unseen_label>"
+        self,
+        labels=None,
+        fill_unseen_labels=True,
+        fill_encoded_label_value=None,
+        fill_label_value="<unseen_label>",
+        include_unseen_class=False,
     ):
         super().__init__()
         self.labels = labels
         self.fill_unseen_labels = fill_unseen_labels
         self.fill_encoded_label_value = fill_encoded_label_value
         self.fill_label_value = fill_label_value
+        self.include_unseen_class = include_unseen_class
 
     def fit(self, y):
         """Fit label encoder.
@@ -355,12 +356,25 @@ class RobustLabelEncoder(LabelEncoder):
         labels = np.arange(len(self.classes_))
         diff = np.setdiff1d(y, labels)
 
-        if diff and not self.fill_unseen_labels:
+        if diff.size > 0 and not self.fill_unseen_labels:
             raise ValueError("y contains previously unseen labels: %s" % str(diff))
 
         y_decoded = [self.classes_[idx] if idx in labels else self.fill_label_value for idx in y]
         return y_decoded
 
+    def get_classes(self):
+        """Returns the values of the unencoded classes.
+        If ``self.include_unseen_class`` is ``True`` include ``self.fill_label_value`` as a class.
+
+        Returns
+        -------
+        classes : array of shape (n_classes,)
+        """
+        if self.include_unseen_class and self.fill_unseen_labels:
+            return np.append(self.classes_, [self.fill_label_value])
+
+        return self.classes_
+
 
 class NALabelEncoder(BaseEstimator, TransformerMixin):
     """Encoder for transforming labels to NA values.
@@ -436,8 +450,8 @@ class RobustOrdinalEncoder(OrdinalEncoder):
 
     The input should be a 2D, array-like input of categorical features. Each column of categorical features will be
     converted to ordinal integers. For a given column of n unique values, seen values will be mapped to integers 0 to
-    n-1 and unseen values will be mapped to integer n. An unseen value is a value that was passed in during the
-    transform step, but not present in the fit step input.
+    n-1 and unseen values will be mapped to the integer n (or to np.nan when unknown_as_nan is True). An unseen value
+    is a value that was passed in during the transform step, but not present in the fit step input.
     This encoder supports inverse_transform, transforming ordinal integers back into categorical features. Unknown
     integers are transformed to None.
 
@@ -458,6 +472,11 @@ class RobustOrdinalEncoder(OrdinalEncoder):
     dtype : number type, default np.float32
         Desired dtype of output.
 
+    unknown_as_nan : boolean, default False
+        When unknown_as_nan is false, unknown values are transformed to n, where n-1 is the last category
+        When unknown_as_nan is true, unknown values are transformed to np.nan
+
+
     Attributes
     ----------
     categories_ : list of arrays
@@ -493,10 +512,11 @@ class RobustOrdinalEncoder(OrdinalEncoder):
 
     """
 
-    def __init__(self, categories="auto", dtype=np.float32):
-        super(RobustOrdinalEncoder, self).__init__(categories, dtype)
+    def __init__(self, categories="auto", dtype=np.float32, unknown_as_nan=False):
+        super(RobustOrdinalEncoder, self).__init__(categories=categories, dtype=dtype)
         self.categories = categories
         self.dtype = dtype
+        self.unknown_as_nan = unknown_as_nan
 
     def fit(self, X, y=None):
         """Fit the RobustOrdinalEncoder to X.
@@ -532,13 +552,19 @@ class RobustOrdinalEncoder(OrdinalEncoder):
 
         """
         X_int, X_mask = self._transform(X, handle_unknown="unknown")
-        # assign the unknowns an integer indicating they are unknown. The largest integer is always reserved for
-        # unknowns
-        for col in range(X_int.shape[1]):
-            mask = X_mask[:, col]
-            X_int[~mask, col] = self.categories_[col].shape[0]
+        if self.unknown_as_nan:
+            # assign the unknowns np.nan
+            X_int = X_int.astype(self.dtype, copy=False)
+            X_int[~X_mask] = np.nan
+        else:
+            # assign the unknowns an integer indicating they are unknown. The largest integer is always reserved for
+            # unknowns
+            for col in range(X_int.shape[1]):
+                mask = X_mask[:, col]
+                X_int[~mask, col] = self.categories_[col].shape[0]
+            X_int = X_int.astype(self.dtype, copy=False)
 
-        return X_int.astype(self.dtype, copy=False)
+        return X_int
 
     def inverse_transform(self, X):
         """Convert the data back to the original representation.
@@ -562,7 +588,7 @@ class RobustOrdinalEncoder(OrdinalEncoder):
 
         """
         check_is_fitted(self, "categories_")
-        X = check_array(X, dtype="numeric")
+        X = check_array(X, dtype="numeric", force_all_finite="allow-nan" if self.unknown_as_nan else True)
 
         n_samples, _ = X.shape
         n_features = len(self.categories_)
@@ -579,7 +605,7 @@ class RobustOrdinalEncoder(OrdinalEncoder):
         found_unknown = {}
         for i in range(n_features):
             labels = X[:, i].astype("int64", copy=False)
-            known_mask = labels != self.categories_[i].shape[0]
+            known_mask = np.isfinite(X[:, i]) if self.unknown_as_nan else (labels != self.categories_[i].shape[0])
             labels *= known_mask
             X_tr[:, i] = self.categories_[i][labels]
             if not np.all(known_mask):
